/*
 * term.c
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#include<types.h>
#include<proc.h>
#include<term.h>
#include<lib.h>


/***************************************************************************************
 *
 *
 *
 ***************************************************************************************/


/*
 * GLOBAL
 * ȥץüΥե饦ɥ롼פɤ
 * return : yes=1 no=0
 */
int isForegrouond(PROC *proc)
{
	if(proc->ctlterm==NULL)return 0;
	return ((TERM_CTL*)proc->ctlterm)->foregrnd==proc->pgid;
}


/*
 * GLOBAL
 * ȥץüץɤ
 * return : yes=1 no=0;
 */
int isCtlproc(PROC *proc)
{
	if(proc->ctlterm==NULL)return 0;
	return ((TERM_CTL*)proc->ctlterm)->ctlProc==proc;
}
